@@ -58,7 +58,7 @@
 #define TclBN_mp_tc_or TclBN_mp_or
 #define TclBN_mp_tc_xor TclBN_mp_xor
 #define TclStaticPackage Tcl_StaticPackage
-#define TclUnusedStubEntry NULL
+#define TclUnusedStubEntry 0
 
 /* See bug 510001: TclSockMinimumBuffers needs plat imp */
 #ifdef _WIN64
@@ -870,6 +870,7 @@ static const TclPlatStubs tclPlatStubs = {
 #ifdef MAC_OSX_TCL /* MACOSX */
     Tcl_MacOSXOpenBundleResources, /* 0 */
     Tcl_MacOSXOpenVersionedBundleResources, /* 1 */
+    TclUnusedStubEntry, /* 2 */
 #endif /* MACOSX */
 };
 
@@ -1641,7 +1642,18 @@ const TclStubs tclStubs = {
     0, /* 646 */
     0, /* 647 */
     0, /* 648 */
-    TclUnusedStubEntry, /* 649 */
+    0, /* 649 */
+    0, /* 650 */
+    0, /* 651 */
+    0, /* 652 */
+    0, /* 653 */
+    0, /* 654 */
+    0, /* 655 */
+    0, /* 656 */
+    0, /* 657 */
+    0, /* 658 */
+    0, /* 659 */
+    TclUnusedStubEntry, /* 660 */
 };
 
 /* !END!: Do not edit above this line. */
