@@ -42,10 +42,11 @@ TclpFindExecutable(
     Tcl_Encoding encoding;
 #if 0
     int length;
-    char buf[PATH_MAX * 2];
-    char name[PATH_MAX * TCL_UTF_MAX + 1];
+    wchar_t buf[PATH_MAX] = L"";
+    char name[PATH_MAX * 3 + 1];
+
     GetModuleFileNameW(NULL, buf, PATH_MAX);
-    cygwin_conv_path(3, buf, name, PATH_MAX);
+    cygwin_conv_path(3, buf, name, sizeof(name));
     length = strlen(name);
     if ((length > 4) && !strcasecmp(name + length - 4, ".exe")) {
 	/* Strip '.exe' part. */
@@ -249,9 +250,9 @@ TclpMatchInDirectory(
 	Tcl_Obj *tailPtr;
 	const char *nativeTail;
 
-	native = Tcl_FSGetNativePath(pathPtr);
+	native = (const char *)Tcl_FSGetNativePath(pathPtr);
 	tailPtr = TclPathPart(interp, pathPtr, TCL_PATH_TAIL);
-	nativeTail = Tcl_FSGetNativePath(tailPtr);
+	nativeTail = (const char *)Tcl_FSGetNativePath(tailPtr);
 	matchResult = NativeMatchType(interp, native, nativeTail, types);
 	if (matchResult == 1) {
 	    Tcl_ListObjAppendElement(interp, resultPtr, pathPtr);
@@ -649,7 +650,7 @@ int
 TclpObjChdir(
     Tcl_Obj *pathPtr)		/* Path to new working directory */
 {
-    const char *path = Tcl_FSGetNativePath(pathPtr);
+    const char *path = (const char *)Tcl_FSGetNativePath(pathPtr);
 
     if (path == NULL) {
 	return -1;
@@ -678,7 +679,7 @@ TclpObjLstat(
     Tcl_Obj *pathPtr,		/* Path of file to stat */
     Tcl_StatBuf *bufPtr)	/* Filled with results of stat call. */
 {
-    return TclOSlstat(Tcl_FSGetNativePath(pathPtr), bufPtr);
+    return TclOSlstat((const char *)Tcl_FSGetNativePath(pathPtr), bufPtr);
 }
 
 /*
@@ -719,7 +720,7 @@ TclpGetNativeCwd(
 #endif /* USEGETWD */
 
     if ((clientData == NULL) || strcmp(buffer, (const char *) clientData)) {
-	char *newCd = ckalloc(strlen(buffer) + 1);
+	char *newCd = (char*)ckalloc(strlen(buffer) + 1);
 
 	strcpy(newCd, buffer);
 	return newCd;
@@ -846,7 +847,7 @@ TclpObjStat(
     Tcl_Obj *pathPtr,		/* Path of file to stat */
     Tcl_StatBuf *bufPtr)	/* Filled with results of stat call. */
 {
-    const char *path = Tcl_FSGetNativePath(pathPtr);
+    const char *path = (const char *)Tcl_FSGetNativePath(pathPtr);
 
     if (path == NULL) {
 	return -1;
@@ -863,7 +864,7 @@ TclpObjLink(
     int linkAction)
 {
     if (toPtr != NULL) {
-	const char *src = Tcl_FSGetNativePath(pathPtr);
+	const char *src = (const char *)Tcl_FSGetNativePath(pathPtr);
 	const char *target = NULL;
 
 	if (src == NULL) {
@@ -909,7 +910,7 @@ TclpObjLink(
 	    Tcl_DecrRefCount(absPtr);
 	    Tcl_DecrRefCount(dirPtr);
 	} else {
-	    target = Tcl_FSGetNativePath(toPtr);
+	    target = (const char*)Tcl_FSGetNativePath(toPtr);
 	    if (target == NULL) {
 		return NULL;
 	    }
@@ -982,7 +983,7 @@ TclpObjLink(
 	}
 	Tcl_DecrRefCount(transPtr);
 
-	length = readlink(Tcl_FSGetNativePath(pathPtr), link, sizeof(link));
+	length = readlink((const char *)Tcl_FSGetNativePath(pathPtr), link, sizeof(link));
 	if (length < 0) {
 	    return NULL;
 	}
@@ -1115,7 +1116,7 @@ TclNativeCreateNativeRep(
 	return NULL;
     }
     Tcl_DecrRefCount(validPathPtr);
-    nativePathPtr = ckalloc(len);
+    nativePathPtr = (char *)ckalloc(len);
     memcpy(nativePathPtr, Tcl_DStringValue(&ds), len);
 
     Tcl_DStringFree(&ds);
@@ -1156,7 +1157,7 @@ TclNativeDupInternalRep(
 
     len = (strlen((const char*) clientData) + 1) * sizeof(char);
 
-    copy = ckalloc(len);
+    copy = (char *)ckalloc(len);
     memcpy(copy, clientData, len);
     return copy;
 }
@@ -1182,7 +1183,7 @@ TclpUtime(
     Tcl_Obj *pathPtr,		/* File to modify */
     struct utimbuf *tval)	/* New modification date structure */
 {
-    return utime(Tcl_FSGetNativePath(pathPtr), tval);
+    return utime((const char *)Tcl_FSGetNativePath(pathPtr), tval);
 }
 
 #if 0
@@ -1193,7 +1194,7 @@ TclOSstat(
     void *cygstat)
 {
     struct stat buf;
-    Tcl_StatBuf *statBuf = cygstat;
+    Tcl_StatBuf *statBuf = (Tcl_StatBuf *)cygstat;
     int result = stat(name, &buf);
 
     statBuf->st_mode = buf.st_mode;
@@ -1216,7 +1217,7 @@ TclOSlstat(
     void *cygstat)
 {
     struct stat buf;
-    Tcl_StatBuf *statBuf = cygstat;
+    Tcl_StatBuf *statBuf = (Tcl_StatBuf *)cygstat;
     int result = lstat(name, &buf);
 
     statBuf->st_mode = buf.st_mode;
